@@ -1,4 +1,4 @@
-/*  Copyright (C) 2014 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2017 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  *
  * DNSSEC public and private key manipulation.
  *
- * The \ref dnssec_key_t is an abstraction for a DNSSEC key pair. If the key
+ * The dnssec_key_t is an abstraction for a DNSSEC key pair. If the key
  * key is initialized with a public key data only, it can be used only for
  * signature verification. In order to use the key for signing, private key
  * has to be loaded. If only a private key is loaded into the structure,
@@ -84,9 +84,7 @@
  */
 typedef enum dnssec_key_algorithm {
 	DNSSEC_KEY_ALGORITHM_INVALID = 0,
-	DNSSEC_KEY_ALGORITHM_DSA_SHA1 = 3,
 	DNSSEC_KEY_ALGORITHM_RSA_SHA1 = 5,
-	DNSSEC_KEY_ALGORITHM_DSA_SHA1_NSEC3 = 6,
 	DNSSEC_KEY_ALGORITHM_RSA_SHA1_NSEC3 = 7,
 	DNSSEC_KEY_ALGORITHM_RSA_SHA256 = 8,
 	DNSSEC_KEY_ALGORITHM_RSA_SHA512 = 10,
@@ -103,6 +101,13 @@ struct dnssec_key;
  */
 typedef struct dnssec_key dnssec_key_t;
 
+/*!
+ * Check whether a DNSKEY algorithm is supported.
+ *
+ * @note: less secure algorithms may go unsupported on purpose.
+ */
+bool dnssec_algorithm_key_support(dnssec_key_algorithm_t algo);
+
 /*!
  * Allocate new DNSSEC key.
  *
@@ -203,6 +208,16 @@ int dnssec_key_set_pubkey(dnssec_key_t *key, const dnssec_binary_t *pubkey);
  */
 unsigned dnssec_key_get_size(const dnssec_key_t *key);
 
+/*!
+ * \brief Compute key ID from public key.
+ *
+ * \param key  Key structure holding the public key.
+ * \param id   Output: key ID in hex.
+ *
+ * \return DNSSEC_E*
+ */
+int dnssec_key_get_keyid(const dnssec_key_t *key, char **id);
+
 /*!
  * Get the RDATA of the DNSSEC key.
  *
@@ -283,6 +298,13 @@ typedef enum dnssec_key_digest {
 	DNSSEC_KEY_DIGEST_SHA384 = 4,
 } dnssec_key_digest_t;
 
+/*!
+ * Check whether a DS algorithm is supported.
+ *
+ * @note: less secure algorithms may go unsupported on purpose.
+ */
+bool dnssec_algorithm_digest_support(dnssec_key_digest_t algo);
+
 /*!
  * Create DS (Delgation Signer) RDATA from DNSSEC key.
  *
