@@ -1,4 +1,4 @@
-/*  Copyright (C) 2014 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2017 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -85,9 +85,5 @@ const char *dnssec_strerror(int error)
 		}
 	}
 
-	static __thread char buffer[128];
-	if (snprintf(buffer, sizeof(buffer), "unknown error %d", error) < 0) {
-		buffer[0] = '\0';
-	}
-	return buffer;
+	return NULL;
 }
