@@ -17,6 +17,7 @@
 #include <assert.h>
 #include <fcntl.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -27,7 +28,6 @@
 #include "key.h"
 #include "keystore.h"
 #include "keystore/internal.h"
-#include "path.h"
 #include "shared.h"
 
 #define DIR_INIT_MODE 0750
@@ -44,13 +44,16 @@ typedef struct pkcs8_dir_handle {
 /*!
  * Get path to a private key in PKCS #8 PEM format.
  */
-#define memdup memdup2
-#define strcdup strcdup2
-#define strstrip strstrip2
-#define sprintf_alloc sprintf_alloc2
-#define const_time_memcmp const_time_memcmp2
-#include <contrib/string.c>
-#define key_path(dir, id) sprintf_alloc2("%s/%s.pem", dir, id)
+static char *key_path(const char *dir, const char *id)
+{
+	char *strp = NULL;
+
+	int ret = asprintf(&strp, "%s/%s.pem", dir, id);
+	if (ret < 0) {
+		return NULL;
+	}
+	return strp;
+}
 
 /*!
  * Get size of the file and reset the position to the beginning of the file.
@@ -169,7 +172,7 @@ static int pkcs8_dir_open(void *_handle, const char *config)
 
 	pkcs8_dir_handle_t *handle = _handle;
 
-	char *path = path_normalize(config);
+	char *path = realpath(config, NULL);
 	if (!path) {
 		return DNSSEC_NOT_FOUND;
 	}
